@@ -2,7 +2,7 @@
 
 ================================================================================
 
-	mingus - Music theory Python package
+	mingus - Music theory Python package, Bar class
 	Copyright (C) 2008, Bart Spaans
 
     This program is free software: you can redistribute it and/or modify
@@ -18,11 +18,6 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-================================================================================
-
-	A Bar is basically a container for NoteContainers (a 
-	NoteContainerContainer if you will, but you shouldn't).
-
 ================================================================================
 
 """
@@ -33,6 +28,11 @@ from Note import Note
 from mt_exceptions import MeterFormatError
 
 class Bar:
+	"""A Bar is basically a container for \
+[refMingusContainersNotecontainer NoteContainers] (a \
+!NoteContainerContainer if you will, but you shouldn't). Bars can be \
+stored together with [refMingusContainersInstrument Instruments] in \
+[refMingusContainersTrack Tracks]."""
 
 	key = 'C'
 	meter = (4, 4)
@@ -49,16 +49,17 @@ class Bar:
 		self.empty()
 
 	def empty(self):
-		"""Empties the Bar, removes all the NoteContainers"""
+		"""Empties the Bar, removes all the \
+[refMingusContainersNotecontainer NoteContainers]"""
 		self.bar = []
 		self.current_beat = 0.0
 		return self.bar
 
 	def set_meter(self, meter):
-		"""Meters in mingus are represented by a single tuple.
-		This function will set the meter of this bar. If the format
-		of the meter is not recognised, a MeterFormatError will
-		be raised."""
+		"""Meters in mingus are represented by a single tuple. \
+This function will set the meter of this bar. If the format \
+of the meter is not recognised, a !MeterFormatError will \
+be raised."""
 
 		if _meter.valid_beat_duration(meter[1]):
 			self.meter = (meter[0], meter[1])
@@ -71,11 +72,12 @@ class Bar:
 
 
 	def place_notes(self, notes, duration):
-		"""Places the NoteContainer notes on the current_beat.
-		Notes can be strings, Notes, list of strings, list of Notes or
-		NoteContainers. Raises a MeterFormatError if the duration is not
-		valid. Returns True if succesful, False otherwise (ie. the Bar 
-		hasn't got enough room for a note of that duration.)"""
+		"""Places the notes on the `current_beat`. Notes can be strings, \
+[refMingusContainersNote Notes], list of strings, list of \
+[refMingusContainersNote Notes] or a [refMingusContainersNotecontainer \
+NoteContainer]. Raises a !MeterFormatError if the duration is not \
+valid. Returns True if succesful, False otherwise (ie. the Bar \
+hasn't got enough room for a note of that duration.)"""
 
 		# note should be able to be strings, lists, Notes or NoteContainers
 		if hasattr(notes, "notes"):
@@ -97,22 +99,27 @@ class Bar:
 		else:
 			raise MeterFormatError, "Not a valid duration '%d'" % duration
 
-	def place_notes_at(self, notes, duration, at):
+	def place_notes_at(self, notes, at):
+		"""Places notes at the index `at`"""
 		for x in self.bar:
 			if x[0] == at:
 				x[0][2] += notes
 
 	def place_rest(self, duration):
+		"""Places a rest of `duration` on the `current_beat`. The same as \
+`place_notes(None, duration)`"""
 		return self.place_notes(None, duration)
 	
 	def remove_last_entry(self):
+		"""Removes the last [refMingusContainersNotecontainer NoteContainer] \
+in the Bar"""
 		self.current_beat -= 1.0 / self.bar[-1][1]
 		self.bar = self.bar[:-1]
 		return self.current_beat
 
 	def is_full(self):
-		"""Returns False if there is room in this Bar for another
-		NoteContainer, True otherwise."""
+		"""Returns False if there is room in this Bar for another \
+[refMingusContainersNotecontainer NoteContainer], True otherwise."""
 		if self.length == 0.0:
 			return False
 		
@@ -122,6 +129,7 @@ class Bar:
 		return False
 
 	def change_note_duration(self, at, to):
+		"""Changes the note duration at index `at` to duration `to`"""
 		if valid_beat_duration(to):
 			diff = 0
 			for x in self.bar:
@@ -133,7 +141,7 @@ class Bar:
 					diff = 1/cur - 1/to
 
 	def get_range(self):
-		"""Returns the highest and the lowest note in a tuble"""
+		"""Returns the highest and the lowest note in a tuple"""
 		min, max = (100000, -1)
 		for cont in self.bar:
 			for note in cont[2]:
@@ -152,14 +160,15 @@ class Bar:
 			return self.place_notes(note_container, 4)
 
 	def __getitem__(self, index):
-		"""Allows you to use [index] notation on Bars to get the 
-		item at the index."""
+		"""Allows you to use `Bar[]` notation on Bars to get the \
+item at the index."""
 		return self.bar[index]
 
 	def __setitem__(self, index, value):
-		"""Allows you to use [] = notation on Bars. The value
-		should be NoteContainer, or a string/list/Note understood
-		by the NoteContainer."""
+		"""Allows you to use [] = notation on Bars. The value \
+should be a [refMingusContainersNotecontainer NoteContainer], \
+or a string/list/[refMingusContainersNote Note] understood \
+by the [refMingusContainersNotecontainer NoteContainer]."""
 
 		if hasattr(value, "notes"):
 			pass
@@ -175,12 +184,15 @@ class Bar:
 		self.bar[index][2] = value
 
 	def __repr__(self):
+		"""Enables str() and repr() for Bars"""
 		return str(self.bar)
 
 	def __len__(self):
+		"""Overloads the len() method for Bars"""
 		return len(self.bar)
 
 	def __eq__(self, other):
+		"""Overloads the '==' operator for Bars"""
 		for b in range(0, len(self.bar) - 1):
 			if self.bar[b] != other.bar[b]:
 				return False
